Package: synthesisr
Type: Package
Title: Import, Assemble, and Deduplicate Bibliographic Datasets
Version: 0.4.1
Authors@R: c(
  person(
    given = "Martin",
    family = "Westgate",
    role = c("aut", "cre"),
    email = "martinjwestgate@gmail.com",
    comment = c(ORCID = "0000-0003-0854-2034")),
  person(
    given = "Eliza",
    family = "Grames",
    role = c("aut"),
    email = "eliza.grames@uconn.edu",
    comment = c(ORCID = "0000-0003-1743-6815")))
Description: A critical first step in systematic literature reviews
  and mining of academic texts is to identify relevant texts from a range
  of sources, particularly databases such as 'Web of Science' or 'Scopus'.
  These databases often export in different formats or with different metadata
  tags. 'synthesisr' expands on the tools outlined by Westgate (2019)
  <doi:10.1002/jrsm.1374> to import bibliographic data from a range of formats
  (such as 'bibtex', 'ris', or 'ciw') in a standard way, and allows merging
  and deduplication of the resulting dataset.
Depends: R (>= 4.1.0)
Imports: dplyr, glue, purrr, rlang, stringdist, stringr, tibble,
        unglue, vroom
Suggests: cli, devtools, knitr, readr, rmarkdown, testthat, usethis
License: GPL-3
URL: https://martinwestgate.com/synthesisr/
BugReports: https://github.com/mjwestgate/synthesisr/issues
LazyData: true
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-03-26 01:57:19 UTC; wes186
Author: Martin Westgate [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0854-2034>),
  Eliza Grames [aut] (ORCID: <https://orcid.org/0000-0003-1743-6815>)
Maintainer: Martin Westgate <martinjwestgate@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-26 13:20:02 UTC
Built: R 4.6.0; ; 2026-04-29 01:48:47 UTC; unix
