# Generated by roxygen2: do not edit by hand

S3method("[",bibliography)
S3method(as.data.frame,bibliography)
S3method(as_tibble,bibliography)
S3method(c,bibliography)
S3method(print,bibliography)
S3method(summary,bibliography)
export(add_line_breaks)
export(as.bibliography)
export(as_tibble)
export(clean_authors)
export(clean_colnames)
export(clean_df)
export(deduplicate)
export(detect_delimiter)
export(detect_lookup)
export(detect_parser)
export(detect_year)
export(extract_unique_references)
export(find_duplicates)
export(format_citation)
export(fuzz_m_ratio)
export(fuzz_partial_ratio)
export(fuzz_token_set_ratio)
export(fuzz_token_sort_ratio)
export(fuzzdist)
export(override_duplicates)
export(parse_bibtex)
export(parse_pubmed)
export(parse_ris)
export(read_refs)
export(review_duplicates)
export(string_cosine)
export(string_dl)
export(string_hamming)
export(string_jaccard)
export(string_jw)
export(string_lcs)
export(string_lv)
export(string_osa)
export(string_qgram)
export(string_soundex)
export(write_bib)
export(write_refs)
export(write_ris)
importFrom(dplyr,bind_rows)
importFrom(glue,glue)
importFrom(rlang,.data)
importFrom(rlang,abort)
importFrom(rlang,warn)
importFrom(stats,xtabs)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(utils,head)
importFrom(utils,read.table)
importFrom(utils,tail)
importFrom(utils,write.table)
importFrom(vroom,default_locale)
importFrom(vroom,vroom)
importFrom(vroom,vroom_lines)
